@@ -150,12 +150,13 @@ public class ColumnConfigGenerator {
 			case USER:
 				break;
 			case VALIDATION:
+				ssb.trustedBackgroundColor("#f6e681");
 				break;
 			case VIEWCOLUMN_OF_DIMENSION:
 				ssb.trustedBackgroundColor("#c3e1fc");
 				break;
 			case VIEWCOLUMN_OF_TIMEDIMENSION:
-				ssb.trustedBackgroundColor("#BAAAF0");
+				ssb.trustedBackgroundColor("#CFC3F7");
 				break;
 			default:
 				break;
